
% This code creates the MPC-figure (Figure 10)

clear;
clc;

addpath('auxiliary')

%% Options and load data

IRF_T  = 6;

cd '..\Stata\Tables'

MPC_lott_ext  = xlsread('vPUB_micro_liquid_lottery.xlsx','A1:C10');
    
%% Rearrange

cd '..\..\Matlab'

MPC        = MPC_lott_ext(:,1);
MPC_conf   = zeros(10,4);

for jj = 1:10

    MPC_conf(jj,1) = MPC_lott_ext(jj,1) + tinv(0.975,MPC_lott_ext(jj,3))*MPC_lott_ext(jj,2);
    MPC_conf(jj,2) = MPC_lott_ext(jj,1) + tinv(0.84,MPC_lott_ext(jj,3))*MPC_lott_ext(jj,2);
    MPC_conf(jj,3) = MPC_lott_ext(jj,1) - tinv(0.84,MPC_lott_ext(jj,3))*MPC_lott_ext(jj,2);
    MPC_conf(jj,4) = MPC_lott_ext(jj,1) - tinv(0.975,MPC_lott_ext(jj,3))*MPC_lott_ext(jj,2);

end 

figure
hold on;
plot([0.5:1:9.5],MPC,'Linewidth',3,'Color',rgb('Mediumblue'),'Marker','*','MarkerSize',7)
plot([0.5:1:9.5],MPC_conf(:,1),'Linewidth',1,'Color',rgb('Mediumblue'))
plot([0.5:1:9.5],MPC_conf(:,2),'Linewidth',1,'Color',rgb('Mediumblue'))
plot([0.5:1:9.5],MPC_conf(:,3),'Linewidth',1,'Color',rgb('Mediumblue'))
plot([0.5:1:9.5],MPC_conf(:,4),'Linewidth',1,'Color',rgb('Mediumblue'))
ciplot_MPC(MPC_conf(:,1),MPC_conf(:,4), [0.5:1:9.5]);
ciplot_MPC(MPC_conf(:,2),MPC_conf(:,3), [0.5:1:9.5]);
yline(0,'Linewidth',1.5);
hold off;
set(gca,'XTick',0:2:10,'XTickLabel',{'0','20','40','60','80','100'},'FontSize',18)
grid on;
set(gca,'Box','on','GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
axis tight
xlim([0 10])
ylim([0 1])
xlabel('Percentile','Interpreter','Latex','Fontsize',22,'FontName','Palatino')
ylabel('Annual MPC','Interpreter','Latex','Fontsize',22,'FontName','Palatino')
title_fig = title('Marginal Propensities to Consume');
set(gca,'Box','on','FontSize',22)
set(title_fig,'fontsize',28,'FontName','Palatino','Interpreter','Latex')
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1000 700])
tightfig;
print(h,'-depsc','..\Figures\Micro\FIG10_Est_MPC_Liq')
