
clear;
clc;

addpath('auxiliary')

% This code creates the figures for the direct-indirect decomposition 
% (Figures 18 and 19)

%% Options
       
% Confidence bands
sign_outer      = 0.05;
sign_inner      = 0.32;

%% Import IRFs

cd '..\Stata\Tables'

all_cons        = xlsread('vPUB_micro_di_plain','A1:C6');
chosen_IRF      = xlsread('vPUB_micro_di_nocy_sep','A1:C6');
chosen_IRF_lott = xlsread('vPUB_micro_di_lottery','A1:C6');

%% Figures

cd '..\..\Matlab'

IRF_length      = size(all_cons,1);
zero_line       = zeros(IRF_length,1);

ci_lower_in     = all_cons(:,1)-tinv(1-sign_inner/2,all_cons(:,3)-4).*all_cons(:,2);
ci_upper_in     = all_cons(:,1)+tinv(1-sign_inner/2,all_cons(:,3)-4).*all_cons(:,2);
ci_lower_in_2   = chosen_IRF(:,1)-tinv(1-sign_inner/2,chosen_IRF(:,3)-4).*chosen_IRF(:,2);
ci_upper_in_2   = chosen_IRF(:,1)+tinv(1-sign_inner/2,chosen_IRF(:,3)-4).*chosen_IRF(:,2);
ci_lower_in_3   = chosen_IRF_lott(:,1)-tinv(1-sign_inner/2,chosen_IRF_lott(:,3)-4).*chosen_IRF_lott(:,2);
ci_upper_in_3   = chosen_IRF_lott(:,1)+tinv(1-sign_inner/2,chosen_IRF_lott(:,3)-4).*chosen_IRF_lott(:,2);

figure
hold on;
plot(zero_line,'black','HandleVisibility','off')
plot(all_cons(1:IRF_length,1),'-','Linewidth',3,'Color',rgb('Mediumblue'))
plot(chosen_IRF(1:IRF_length,1),'-.','Linewidth',3,'Color',rgb('Crimson'))
plot(ci_lower_in_2,'b','Linewidth',1,'Color',rgb('Crimson'))
plot(ci_upper_in_2,'b','Linewidth',1,'Color',rgb('Crimson'))
ciplot_micro(ci_lower_in_2,ci_upper_in_2,1:6,[0.9412,0.5647,0.5647],0.15);     
plot(ci_lower_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
plot(ci_upper_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
ciplot_micro(ci_lower_in,ci_upper_in,1:6,[0.5,0.5,0.9],0.15);
hold off;
legend({'Unconditional (direct + indirect)','Conditioned on income (direct)'},'FontName','Palatino','FontSize',20,'Interpreter','Latex','Location','southwest')
axis tight
grid on
set(gca,'Box','on','FontSize',20,'GridLineStyle','--')
xlim([1 6])
xticks(1:6)
xticklabels({'0','1','2','3','4','5'})    
ax = gca;
ax.GridAlpha = .5;
ylabel('Percent','fontsize',22,'FontName','Palatino','Interpreter','Latex')
xlabel('Years','fontsize',22,'FontName','Palatino','Interpreter','Latex')
title('Consumption Expenditures','fontsize',26,'FontName','Palatino','Interpreter','Latex');
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 800 600])
tightfig;
print(h,'-depsc','..\Figures\Micro\FIG18_IRFs_cond_inc')

figure
hold on;
plot(zero_line,'black','HandleVisibility','off')
plot(all_cons(1:IRF_length,1),'-','Linewidth',3,'Color',rgb('Mediumblue'))
plot(chosen_IRF(1:IRF_length,1),'-.','Linewidth',3,'Color',rgb('Crimson'))
plot(chosen_IRF_lott(1:IRF_length,1),'-.','Linewidth',3,'Color',rgb('Green'))
plot(ci_lower_in_3,'b','Linewidth',1,'Color',rgb('Green'))
plot(ci_upper_in_3,'b','Linewidth',1,'Color',rgb('Green'))
ciplot_micro(ci_lower_in_3,ci_upper_in_3,1:6,[0,0.5,0],0.1);
plot(ci_lower_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
plot(ci_upper_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
ciplot_micro(ci_lower_in,ci_upper_in,1:6,[0.5,0.5,0.9],0.15);
hold off;
legend({'Unconditional (direct + indirect)','Conditioned on income (direct)','IV-Estimation (direct)'},'FontName','Palatino','FontSize',20,'Interpreter','Latex','Location','southwest')
axis tight
grid on
set(gca,'Box','on','FontSize',20,'GridLineStyle','--')
xlim([1 6])
xticks(1:6)
xticklabels({'0','1','2','3','4','5'})    
ax = gca;
ax.GridAlpha = .5;
ylabel('Percent','fontsize',22,'FontName','Palatino','Interpreter','Latex')
xlabel('Years','fontsize',22,'FontName','Palatino','Interpreter','Latex')
title('Consumption Expenditures','fontsize',26,'FontName','Palatino','Interpreter','Latex');
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 800 600])
tightfig;
print(h,'-depsc','..\Figures\Micro\FIG19_IRFs_cond_inc_IV')
