
clear;
clc;

addpath('auxiliary')

%% Setup and definitions

directory_data     = '..\Stata\Tables';
directory_figures  = '..\Figures\Micro';

var_labels_liquidgroups_rti = {'Consumption','Consumption-Income Ratio','Disposable Income','Saving','Financial Income (Net)','Nonfinancial Income','Capital Revenues','Capital Expenditures','Interest Income','Dividend Income','Capital Gains (Housing)','Capital Gains (Risky Assets)'};
var_labels_niegroups_rti    = {'Consumption','Disposable Income','Saving','Financial Income (Net)','Nonfinancial Income','Capital Revenues','Capital Expenditures'};

IRF_T = 6;                                 % IRF horizon (including h=0)

%% Import micro estimates / descriptive statistics

oldFolder = cd(directory_data);

liquidgroups_cons_excl_housing   = xlsread('vPUB_micro_liquidgroups_rti_cons_excl_housing_a10.xlsx','A1:C120');
liquidgroups_cons_inc_diff       = xlsread('vPUB_micro_liquidgroups_cons_inc_diff_10.xlsx','A1:C120');
liquidgroups_net_inc             = xlsread('vPUB_micro_liquidgroups_rti_net_inc_a10.xlsx','A1:C120');
liquidgroups_net_saving          = xlsread('vPUB_micro_liquidgroups_rti_net_saving_a10.xlsx','A1:C120');
liquidgroups_cap_inc             = xlsread('vPUB_micro_liquidgroups_rti_cap_inc_a10.xlsx','A1:C120');
liquidgroups_nf_income           = xlsread('vPUB_micro_liquidgroups_rti_nf_income_a10.xlsx','A1:C120');
liquidgroups_cap_inc_gross       = xlsread('vPUB_micro_liquidgroups_rti_cap_inc_gross_a10.xlsx','A1:C120');
liquidgroups_cap_exp_gross       = xlsread('vPUB_micro_liquidgroups_rti_cap_exp_gross_a10.xlsx','A1:C120');
liquidgroups_cap_inc_interest    = xlsread('vPUB_micro_liquidgroups_rti_cap_inc_interest_a10.xlsx','A1:C120');
liquidgroups_cap_inc_dividends   = xlsread('vPUB_micro_liquidgroups_rti_cap_inc_dividends_a10.xlsx','A1:C120');        
liquidgroups_capgains_housing    = xlsread('vPUB_micro_liquidgroups_rti_uncapgains_housing_a10.xlsx','A1:C120');
liquidgroups_capgains_risky      = xlsread('vPUB_micro_liquidgroups_rti_uncapgains_risky_a10.xlsx','A1:C120');

niegroups_cons_excl_housing      = xlsread('vPUB_micro_niegroups_rti_cons_excl_housing_a10.xlsx','A1:C120');
niegroups_net_inc                = xlsread('vPUB_micro_niegroups_rti_net_inc_a10.xlsx','A1:C120');
niegroups_net_saving             = xlsread('vPUB_micro_niegroups_rti_net_saving_a10.xlsx','A1:C120');
niegroups_cap_inc                = xlsread('vPUB_micro_niegroups_rti_cap_inc_a10.xlsx','A1:C120');
niegroups_nf_income              = xlsread('vPUB_micro_niegroups_rti_nf_income_a10.xlsx','A1:C120');
niegroups_cap_inc_gross          = xlsread('vPUB_micro_niegroups_rti_cap_inc_gross_a10.xlsx','A1:C120');
niegroups_cap_exp_gross          = xlsread('vPUB_micro_niegroups_rti_cap_exp_gross_a10.xlsx','A1:C120');

incomegroups_cons_excl_housing   = xlsread('vPUB_micro_incomegroups_rti_cons_excl_housing_a10.xlsx','A1:C120');
wealthgroups_cons_excl_housing   = xlsread('vPUB_micro_wealthgroups_rti_bal_cons_excl_housing_a10.xlsx','A1:C120');

liquidgroups_nie                 = xlsread('vPUB_micro_liquidgroups_nie.xlsx','A1:D10');
niegroups_nie                    = xlsread('vPUB_micro_niegroups_nie.xlsx','A1:D10');
incomegroups_nie                 = xlsread('vPUB_micro_incomegroups_nie.xlsx','A1:D10');
wealthgroups_nie                 = xlsread('vPUB_micro_wealthgroups_nie_bal.xlsx','A1:D10');

cd(oldFolder) 

%% Re-arrange data   

nb_liquidgroups = size(liquidgroups_cons_excl_housing,1)/IRF_T;
bmat_liquidgroups(:,:,1)        = flipud(reshape(liquidgroups_cons_excl_housing(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,2)        = flipud(reshape(liquidgroups_cons_inc_diff(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,3)        = flipud(reshape(liquidgroups_net_inc(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,4)        = flipud(reshape(liquidgroups_net_saving(:,1),[IRF_T,nb_liquidgroups]));        
bmat_liquidgroups(:,:,5)        = flipud(reshape(liquidgroups_cap_inc(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,6)        = flipud(reshape(liquidgroups_nf_income(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,7)        = flipud(reshape(liquidgroups_cap_inc_gross(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,8)        = flipud(reshape(liquidgroups_cap_exp_gross(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,9)        = flipud(reshape(liquidgroups_cap_inc_interest(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,10)       = flipud(reshape(liquidgroups_cap_inc_dividends(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,11)       = flipud(reshape(liquidgroups_capgains_housing(:,1),[IRF_T,nb_liquidgroups]));
bmat_liquidgroups(:,:,12)       = flipud(reshape(liquidgroups_capgains_risky(:,1),[IRF_T,nb_liquidgroups]));

bmat_liquidgroups_2D  = zeros(IRF_T/2,nb_liquidgroups,size(bmat_liquidgroups,3));
for kk=1:size(bmat_liquidgroups,3)    
    bmat_liquidgroups_2D(:,:,kk)=...
    [bmat_liquidgroups(1,:,kk)+bmat_liquidgroups(2,:,kk); bmat_liquidgroups(3,:,kk)+bmat_liquidgroups(4,:,kk); bmat_liquidgroups(5,:,kk)+bmat_liquidgroups(6,:,kk)]/2;
end

nb_niegroups  = size(niegroups_cons_excl_housing,1)/IRF_T;
bmat_niegroups(:,:,1)      = flipud(reshape(niegroups_cons_excl_housing(:,1),[IRF_T,nb_niegroups]));
bmat_niegroups(:,:,2)      = flipud(reshape(niegroups_net_inc(:,1),[IRF_T,nb_niegroups]));
bmat_niegroups(:,:,3)      = flipud(reshape(niegroups_net_saving(:,1),[IRF_T,nb_niegroups]));        
bmat_niegroups(:,:,4)      = flipud(reshape(niegroups_cap_inc(:,1),[IRF_T,nb_niegroups]));
bmat_niegroups(:,:,5)      = flipud(reshape(niegroups_nf_income(:,1),[IRF_T,nb_niegroups]));
bmat_niegroups(:,:,6)      = flipud(reshape(niegroups_cap_inc_gross(:,1),[IRF_T,nb_niegroups]));
bmat_niegroups(:,:,7)      = flipud(reshape(niegroups_cap_exp_gross(:,1),[IRF_T,nb_niegroups]));            

bmat_niegroups_2D  = zeros(IRF_T/2,nb_niegroups,size(bmat_niegroups,3));
for kk=1:size(bmat_niegroups,3)    
    bmat_niegroups_2D(:,:,kk)=...
    [bmat_niegroups(1,:,kk)+bmat_niegroups(2,:,kk); bmat_niegroups(3,:,kk)+bmat_niegroups(4,:,kk); bmat_niegroups(5,:,kk)+bmat_niegroups(6,:,kk)]/2;
end

nb_incomegroups  = size(incomegroups_cons_excl_housing,1)/IRF_T;
bmat_incomegroups(:,:,1)      = flipud(reshape(incomegroups_cons_excl_housing(:,1),[IRF_T,nb_incomegroups]));

bmat_incomegroups_2D  = zeros(IRF_T/2,nb_incomegroups,size(bmat_incomegroups,3));   
bmat_incomegroups_2D(:,:,1)=...
[bmat_incomegroups(1,:,1)+bmat_incomegroups(2,:,1); bmat_incomegroups(3,:,1)+bmat_incomegroups(4,:,1); bmat_incomegroups(5,:,1)+bmat_incomegroups(6,:,1)]/2;

nb_wealthgroups  = size(wealthgroups_cons_excl_housing,1)/IRF_T;
bmat_wealthgroups(:,:,1)      = flipud(reshape(wealthgroups_cons_excl_housing(:,1),[IRF_T,nb_wealthgroups]));

bmat_wealthgroups_2D  = zeros(IRF_T/2,nb_wealthgroups,size(bmat_wealthgroups,3));   
bmat_wealthgroups_2D(:,:,1)=...
[bmat_wealthgroups(1,:,1)+bmat_wealthgroups(2,:,1); bmat_wealthgroups(3,:,1)+bmat_wealthgroups(4,:,1); bmat_wealthgroups(5,:,1)+bmat_wealthgroups(6,:,1)]/2;

%% Figures 


% Liquid asset distribution

figure
for kk=1:2
    %3D
    subplot(4,2,kk)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk))
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    zlim([min(min(min(bmat_liquidgroups(:,:,1:4)))) max(max(max(bmat_liquidgroups(:,:,1:4))))])
    if kk==2
        zlim([-2 1.25])  
    end
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    ylim([min(min(min(bmat_liquidgroups_2D(:,:,1:4)))) max(max(max(bmat_liquidgroups_2D(:,:,1:4))))])
    if kk==2
        ylim([-1.25 0.75])
    end
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==2
        legend('0-1 years','2-3 years','4-5 years','Location','Southwest','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end
 end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG8_liquidgroups_rti_1')
cd(oldFolder)
   
figure
for kk=3:4
    %3D
    subplot(4,2,kk-2)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk))
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    zlim([min(min(min(bmat_liquidgroups(:,:,1:4)))) max(max(max(bmat_liquidgroups(:,:,1:4))))])
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk-2+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    ylim([min(min(min(bmat_liquidgroups_2D(:,:,1:4)))) max(max(max(bmat_liquidgroups_2D(:,:,1:4))))])
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==4
        legend('0-1 years','2-3 years','4-5 years','Location','Southeast','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG9_liquidgroups_rti_2')
cd(oldFolder)

figure
for kk=5:6
    %3D
    subplot(4,2,kk-4)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk))
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    zlim([min(min(min(bmat_liquidgroups(:,:,5:6)))) max(max(max(bmat_liquidgroups(:,:,5:6))))])
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk-4+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    ylim([min(min(min(bmat_liquidgroups_2D(:,:,5:6)))) max(max(max(bmat_liquidgroups_2D(:,:,5:6))))])
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==6
        legend('0-1 years','2-3 years','4-5 years','Location','Northeast','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG11_liquidgroups_rti_3')
cd(oldFolder)

figure
for kk=7:8    
    %3D
    subplot(4,2,kk-6)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk))
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    zlim([min(min(min(bmat_liquidgroups(:,:,7:8)))) max(max(max(bmat_liquidgroups(:,:,7:8))))])
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk-6+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    ylim([min(min(min(bmat_liquidgroups_2D(:,:,7:8)))) max(max(max(bmat_liquidgroups_2D(:,:,7:8))))])
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==8
        legend('0-1 years','2-3 years','4-5 years','Location','Northeast','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end  
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG12_liquidgroups_rti_4')
cd(oldFolder)

figure
for kk=9:10    
    %3D
    subplot(4,2,kk-8)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk));
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    if kk==9
        zlim([min(min(min(bmat_liquidgroups(:,:,9:10)))) max(max(max(bmat_liquidgroups(:,:,9:10))))])
    elseif kk==10
        zlim([min(min(min(bmat_liquidgroups(:,:,9:10))))/10 max(max(max(bmat_liquidgroups(:,:,9:10))))/10])
    end
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk-8+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    if kk==9
        ylim([min(min(min(bmat_liquidgroups(:,:,9:10)))) max(max(max(bmat_liquidgroups(:,:,9:10))))])
    elseif kk==10
        ylim([min(min(min(bmat_liquidgroups(:,:,9:10))))/10 max(max(max(bmat_liquidgroups(:,:,9:10))))/10])
    end
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==10
        legend('0-1 years','2-3 years','4-5 years','Location','Northwest','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end  
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG13_liquidgroups_rti_5')
cd(oldFolder)

figure
for kk=11:12    
    %3D
    subplot(4,2,kk-10)
    surf([0.5:1:9.5],[0:1:5],bmat_liquidgroups(:,:,kk));
    [caz_strd,cel_strd] = view;
    view([-55,30])
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    set(gca,'YTick',0:1:IRF_T-1,'YTickLabel',{'5','4','3','2','1','0'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    if kk==11
        zlim([min(min(min(bmat_liquidgroups(:,:,11:12)))) max(max(max(bmat_liquidgroups(:,:,11:12))))])
    elseif kk==12
        zlim([min(min(min(bmat_liquidgroups(:,:,11:12))))/10 max(max(max(bmat_liquidgroups(:,:,11:12))))/10])
    end
    colormap default
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Year','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    zlabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    title_fig = title(var_labels_liquidgroups_rti(kk));
    set(title_fig,'fontsize',22,'FontName','Palatino','Interpreter','Latex')
    %2D
    subplot(4,2,kk-10+2)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_liquidgroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.5,'LineWidth',1)
    xlim([0 10])
    if kk==11
        ylim([min(min(min(bmat_liquidgroups(:,:,11:12)))) max(max(max(bmat_liquidgroups(:,:,11:12))))])
    elseif kk==12
        ylim([min(min(min(bmat_liquidgroups(:,:,11:12))))/10 max(max(max(bmat_liquidgroups(:,:,11:12))))/10])
    end
    xlabel('Percentile','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',20,'FontName','Palatino')
    if kk==12
        legend('0-1 years','2-3 years','4-5 years','Location','Northwest','fontsize',18,'FontName','Palatino','Interpreter','Latex')  
    end  
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1620])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','-r400','FIG14_liquidgroups_rti_6')
cd(oldFolder)


% Net interest rate exposure distribution

figure
for kk=1:3
    %3D
    subplot(1,3,kk)
    hold on;
    plot([0.5:1:9.5],bmat_niegroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_niegroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_niegroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_niegroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_niegroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_niegroups/5:nb_niegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    xlim([0 10])
    ylim([min(min(min(bmat_niegroups_2D(:,:,1:3)))) max(max(max(bmat_niegroups_2D(:,:,1:3))))])
    if kk==3
        legend('0-1 years','2-3 years','4-5 years','Location','South','fontsize',20,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Percentile','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    title_fig = title(var_labels_niegroups_rti(kk));
    set(title_fig,'fontsize',28,'FontName','Palatino','Interpreter','Latex')
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1800 330])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','FIG15_niegroups_rti_1')    
cd(oldFolder)

figure
for kk=4:7
    %3D
    subplot(2,2,kk-3)
    hold on;
    plot([0.5:1:9.5],bmat_niegroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_niegroups_2D(2,:,kk),'Linewidth',3,'Color',rgb('Grey'),'Linestyle','-.','Marker','+','MarkerSize',6)
    plot([0.5:1:9.5],bmat_niegroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'Marker','x','MarkerSize',8)
    plot([0.5:1:9.5],bmat_niegroups_2D(3,:,kk),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    plot([0.5:1:9.5],bmat_niegroups_2D(1,:,kk),'Linewidth',3,'Color',rgb('Navy'),'marker','x','MarkerSize',8)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_niegroups/5:nb_niegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    axis tight
    xlim([0 10])
    ylim([min(min(min(bmat_niegroups_2D(:,:,4:7)))) max(max(max(bmat_niegroups_2D(:,:,4:7))))])
    if kk==5
        legend('0-1 years','2-3 years','4-5 years','Location','Northeast','fontsize',20,'FontName','Palatino','Interpreter','Latex')
    end
    if kk>5
        xlabel('Percentile','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    end
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    title_fig = title(var_labels_niegroups_rti(kk));
    set(title_fig,'fontsize',28,'FontName','Palatino','Interpreter','Latex')
end
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 750])
tightfig;
oldFolder=cd(directory_figures);
print(h,'-depsc','FIG16_niegroups_rti_2')
cd(oldFolder)


% Additional distributions

figure
    subplot(5,2,1)
    hold on;
    plot([0.5:1:9.5],niegroups_nie(:,2)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    plot([0.5:1:9.5],niegroups_nie(:,3)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle','-','Marker','s','MarkerSize',5)
    plot([0.5:1:9.5],niegroups_nie(:,4)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_niegroups/5:nb_niegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    box off;
    xlim([0 10])
    ylim([-250 160])
    legend('P90','Median','P10','Location','Southeast','fontsize',17,'FontName','Palatino','Interpreter','Latex') 
    ylabel({'\textbf{Net $i$-Exposure}','\textbf{Distr.}','(USD 1,000)'},'Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    title_fig = title('Net $i$-Exposure (Descriptive)');
    set(title_fig,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    
    subplot(5,2,2)
    hold on;
    plot([0.5:1:9.5],bmat_niegroups_2D(3,:,1),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_niegroups/5:nb_niegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    xlim([0 10])
    ylim([-1.95 1.7])
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    title_fig = title('Consumption (IRF)');
    set(title_fig,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    legend('0-1 years','Location','Southeast','fontsize',17,'FontName','Palatino','Interpreter','Latex')

    subplot(5,2,3)
    hold on;   
    plot([0.5:1:9.5],liquidgroups_nie(:,2)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    plot([0.5:1:9.5],liquidgroups_nie(:,3)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle','-','Marker','s','MarkerSize',5)
    plot([0.5:1:9.5],liquidgroups_nie(:,4)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    box off;
    xlim([0 10])
    ylim([-250 160])
    ylabel({'\textbf{Liquid Asset}','\textbf{Distr.}','(USD 1,000)'},'Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    
    subplot(5,2,4)
    hold on;
    plot([0.5:1:9.5],bmat_liquidgroups_2D(3,:,1),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_liquidgroups/5:nb_liquidgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    xlim([0 10])
    ylim([-1.95 1.7])
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino') 
 
    subplot(5,2,5)
    hold on;
    plot([0.5:1:9.5],incomegroups_nie(:,2)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    plot([0.5:1:9.5],incomegroups_nie(:,3)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle','-','Marker','s','MarkerSize',5)
    plot([0.5:1:9.5],incomegroups_nie(:,4)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_incomegroups/5:nb_incomegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    box off;
    xlim([0 10])
    ylim([-250 160])
    ylabel({'\textbf{Income}','\textbf{Distr.}','(USD 1,000)'},'Interpreter','Latex','Fontsize',26,'FontName','Palatino')
   
    subplot(5,2,6)
    hold on;
    plot([0.5:1:9.5],bmat_incomegroups_2D(3,:,1),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_incomegroups/5:nb_incomegroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    xlim([0 10])
    ylim([-1.95 1.7])
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
 
    subplot(5,2,7)
    hold on;
    plot([0.5:1:9.5],wealthgroups_nie(:,2)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    plot([0.5:1:9.5],wealthgroups_nie(:,3)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle','-','Marker','s','MarkerSize',5)
    plot([0.5:1:9.5],wealthgroups_nie(:,4)/1000,'Linewidth',3,'Color',rgb('Black'),'Linestyle',':','Marker','s','MarkerSize',3)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_wealthgroups/5:nb_wealthgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    box off;
    xlim([0 10])
    ylim([-250 160])
    xlabel('Percentile','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    ylabel({'\textbf{Net Worth}','\textbf{Distr.}','(USD 1,000)'},'Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    
    subplot(5,2,8)
    hold on;
    plot([0.5:1:9.5],bmat_wealthgroups_2D(3,:,1),'Linewidth',3,'Color',rgb('Mediumblue'),'Linestyle',':','Marker','*','MarkerSize',7)
    yline(0,'Linewidth',1.5);
    hold off;
    set(gca,'XTick',0:nb_wealthgroups/5:nb_wealthgroups,'XTickLabel',{'0','20','40','60','80','100'},'FontSize', 18)
    grid on;
    set(gca,'GridLineStyle','--','gridalpha',0.25,'LineWidth',1)
    xlim([0 10])
    ylim([-1.95 1.7])
    xlabel('Percentile','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
    ylabel('Percent','Interpreter','Latex','Fontsize',26,'FontName','Palatino')
 
h = gcf;
set(h, 'PaperPositionMode','auto','Position',[0 0 1150 1750])
tightfig_AT;
oldFolder=cd(directory_figures);
print(h,'-depsc','FIG17_nie_vs_IRFs_rti') 
cd(oldFolder)

%% Numerical output

oldFolder = cd('..');

out1liquid = {'Liquid asset distribution';'';'Consumption';'';'';'Disposable Income';'';'';'Saving'};
out2 = {'0-1 years';'2-3 years';'4-5 years';'0-1 years';'2-3 years';'4-5 years';'0-1 years';'2-3 years';'4-5 years'};
out3 = {'0 to 10 %','10 to 20 %','20 to 30 %','30 to 40 %','40 to 50 %','50 to 60 %','60 to 70 %','70 to 80 %','80 to 90 %','90 to 100 %'};
out4liquid = [bmat_liquidgroups_2D(3,:,1);bmat_liquidgroups_2D(2,:,1);bmat_liquidgroups_2D(1,:,1);...
    bmat_liquidgroups_2D(3,:,3);bmat_liquidgroups_2D(2,:,3);bmat_liquidgroups_2D(1,:,3);...
    bmat_liquidgroups_2D(3,:,4);bmat_liquidgroups_2D(2,:,4);bmat_liquidgroups_2D(1,:,4)];
xlswrite('IRFs_overview.xlsx',out1liquid,'Sheet1','A1')
xlswrite('IRFs_overview.xlsx',out2,'Sheet1','B3')
xlswrite('IRFs_overview.xlsx',out3,'Sheet1','C2')
xlswrite('IRFs_overview.xlsx',out4liquid,'Sheet1','C3')

out1nie = {'Net interest rate exposure distribution';'';'Consumption';'';'';'Disposable Income';'';'';'Saving'};
out4nie=[bmat_niegroups_2D(3,:,1);bmat_niegroups_2D(2,:,1);bmat_niegroups_2D(1,:,1);...
    bmat_niegroups_2D(3,:,2);bmat_niegroups_2D(2,:,2);bmat_niegroups_2D(1,:,2);...
    bmat_niegroups_2D(3,:,3);bmat_niegroups_2D(2,:,3);bmat_niegroups_2D(1,:,3)];
xlswrite('IRFs_overview.xlsx',out1nie,'Sheet1','A16')
xlswrite('IRFs_overview.xlsx',out2,'Sheet1','B18')
xlswrite('IRFs_overview.xlsx',out3,'Sheet1','C17')
xlswrite('IRFs_overview.xlsx',out4nie,'Sheet1','C18')

out5={'From "The Transmission of Monetary Policy under the Microscope" by M. B. Holm, P. Paul, and A. Tischbirek, 2021'};
xlswrite('IRFs_overview.xlsx',out5,'Sheet1','A31')

cd(oldFolder)
