
clear;
clc;


addpath('auxiliary')
% This code creates the micro-macro impulse responses in Figure 7

%% Options

var_labels_paper = {'Consumption Expenditures','Disposable Income','Nonfinancial Income', ...
                    'Capital Revenues','Capital Expenditures','Debt', ...
                    'Wealth','Risky Financial Assets','Safe Assets'};

IRF_T       = 6;    % Size of IRFs
          
sign_outer  = 0.05; % Significance level for confidence bands
sign_inner  = 1/3;
k_lp        = 3;    % Number of controls in local projections (excl. constant)

%% Import IRFs

cd '..\Stata\Tables'

cap_exp_gross             = xlsread('vPUB_micro_all_rta_bal_cap_exp_gross.xlsx','A1:C6');
cap_inc_gross             = xlsread('vPUB_micro_all_rta_bal_cap_inc_gross.xlsx','A1:C6');
cons_excl_housing         = xlsread('vPUB_micro_all_rta_bal_cons_excl_housing.xlsx','A1:C6');
net_inc                   = xlsread('vPUB_micro_all_rta_bal_net_inc.xlsx','A1:C6');
non_financial_inc         = xlsread('vPUB_micro_all_rta_bal_nf_income.xlsx','A1:C6');
wealth                    = xlsread('vPUB_micro_all_rta_bal_wealth.xlsx','A1:C6');
debt                      = xlsread('vPUB_micro_all_rta_bal_debt.xlsx','A1:C6');
risky                     = xlsread('vPUB_micro_all_rta_bal_risky.xlsx','A1:C6');
safe                      = xlsread('vPUB_micro_all_rta_bal_safe.xlsx','A1:C6');

%% Re-arrange data

bSEmat_p(:,:,1)    = cons_excl_housing(:,1:3);
bSEmat_p(:,:,2)    = net_inc(:,1:3);
bSEmat_p(:,:,3)    = non_financial_inc(:,1:3);
bSEmat_p(:,:,4)    = cap_inc_gross(:,1:3);        
bSEmat_p(:,:,5)    = cap_exp_gross(:,1:3);
bSEmat_p(:,:,6)    = debt(:,1:3);
bSEmat_p(:,:,7)    = wealth(:,1:3);
bSEmat_p(:,:,8)    = risky(:,1:3);
bSEmat_p(:,:,9)    = safe(:,1:3);

%% Figures

cd '..\..\Matlab'

zero_line = zeros(IRF_T,1);

figure
for kk=1:9
    ci_lower_in     = bSEmat_p(:,1,kk)-tinv(1-sign_inner/2,bSEmat_p(:,3,kk)-k_lp-1).*bSEmat_p(:,2,kk);
    ci_upper_in     = bSEmat_p(:,1,kk)+tinv(1-sign_inner/2,bSEmat_p(:,3,kk)-k_lp-1).*bSEmat_p(:,2,kk);
    ci_lower_out    = bSEmat_p(:,1,kk)-tinv(1-sign_outer/2,bSEmat_p(:,3,kk)-k_lp-1).*bSEmat_p(:,2,kk);
    ci_upper_out    = bSEmat_p(:,1,kk)+tinv(1-sign_outer/2,bSEmat_p(:,3,kk)-k_lp-1).*bSEmat_p(:,2,kk);
    
    subplot(3,3,kk)
    hold on;
    plot(bSEmat_p(:,1,kk),'b','Linewidth',3,'Color',rgb('Mediumblue')) 
    plot(ci_lower_out,'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(ci_lower_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(ci_upper_in,'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(ci_upper_out,'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot_adj(ci_lower_in,ci_upper_in);
    ciplot_adj(ci_lower_out,ci_upper_out);
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(var_labels_paper(kk));
    set(gca,'Box','on','FontSize',16)
    xlim([1 IRF_T])
    xticks(1:IRF_T)
    xticklabels({'0','1','2','3','4','5'})
    ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    if kk >= 7
        xlabel('Year','fontsize',18,'FontName','Palatino','Interpreter','Latex')        
    end
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h,'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1800 1200])
tightfig;
print(h,'-depsc','..\Figures\Micro\FIG7_micro_macro_IR')
