global version vPUB

global w5_data "data folder"
global w5_log "log folder"
global w5_figures "figure folder"
global w5_tables "table folder"


u $w5_data/${version}_monetary_all_pre_sample_selection, replace 

********************************************************************************
* Standard trimming
gen sampleEst = 1
replace sampleEst = 0 if wealth_a == 0 
replace sampleEst = 0 if net_inc_a <= grunnbelop
replace sampleEst = 0 if cons_excl_housing_a <= grunnbelop
keep if sampleEst == 1
drop sampleEst


* define liquid asset groups to estimate MPCs within

global group_type liquid

gen Bliquid_assets_a=Bdeposits_a+Bstocks_a+Bmfund_a+Bbonds_a+Bpublic_assets_PE_a

egen group = xtile(Bliquid_assets_a), n(10) by(year)



* make the conditional trimming as in the lottery paper
preserve
gen trim = 0
keep if lottery_a != 0
sort lottery_a
qui gen nnn = _n
qui replace nnn = . if lottery_a == .
qui egen NNN = max(nnn)
qui gen qqq = nnn/NNN
qui gen q100lott = ceil(qqq*100)
drop nnn NNN qqq

forvalues j = 1/100 {
	di `j'
	forval yy = 1994/2015 {
	qui su cons_excl_housing_a if q100lott == `j' & year == `yy', det
	qui su cons_excl_housing_a if q100lott == `j' & cons_excl_housing_a > r(p95) & year == `yy', det
	replace trim = 1 if q100lott == `j' & cons_excl_housing_a > r(p50) & year == `yy'
	
	qui su cons_excl_housing_a if q100lott == `j' & year == `yy', det
	qui su cons_excl_housing_a if q100lott == `j' & cons_excl_housing_a < r(p5) & year == `yy', det
	replace trim = 1 if q100lott == `j' & cons_excl_housing_a < r(p50) & year == `yy'
	}
}
keep if trim == 0
drop trim
save $w5_data/_tempLott, replace
restore

gen trim = 0
keep if lottery_a == 0
forval j = 1/10 {
	forval yy = 1994/2015 {
		qui su cons_excl_housing_a if group == `j' & year == `yy', det
		qui su cons_excl_housing_a if group == `j' & cons_excl_housing_a > r(p95) & year == `yy', det
		qui replace trim = 1 if group == `j' & cons_excl_housing_a > r(p50) & year == `yy'
		
		qui su cons_excl_housing_a if group == `j' & year == `yy', det
		qui su cons_excl_housing_a if group == `j' & cons_excl_housing_a < r(p5) & year == `yy', det
		qui replace trim = 1 if group == `j' & cons_excl_housing_a < r(p50) & year == `yy'
	}
}

keep if trim == 0
drop trim
append using $w5_data/_tempLott




********************************************************************************
* open log-file

cap log close
log using ${w5_log}/${version}_micro_${group_type}_lottery.log, replace

drop if lottery_a != 0 & (lottery_a <= 1000 | lottery_a >= 150000)
bys lnr: egen sumLott = sum(lottery_a != 0)
keep if sumLott == 1


bys lnr (year): gen win = sum(lottery_a != 0)
replace win = 0 if lottery_a != 0

qui tab year, gen(y_)	


********************************************************************************
* Contemporaneous MPC regression by group
********************************************************************************

* calculate number of  used
qui su group, meanonly 
local group_nb = r(max)		
	
* make matrices ready
matrix res = J(`group_nb',1,0)
matrix seRes = J(`group_nb',1,0)
matrix NObs = J(`group_nb',1,0)	
eststo clear

forval kk=1/`group_nb' {

	preserve
	keep if group == `kk'

	eststo: qui areg cons_excl_housing_a lottery_a y_* if group == `kk' & win == 0, absorb(lnr) robust cluster(lnr)

	*store results
	matrix beta = e(b)
	matrix res[`kk',1] = beta[1,1]
	mat VV = e(V)
	matrix seRes[`kk',1] = sqrt(VV[1,1])
	matrix NObs[`kk',1] = e(N)
		
	* show estimates
	esttab, keep(lottery_a) se compress replace
	eststo clear

	restore
}

putexcel set ${w5_tables}/${version}_micro_${group_type}_lottery.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)


********************************************************************************
* close log file

log close
