
/*
This file rund all the main regressions for Holm, Tischbirek, and Paul
*/



clear
set more off


********************************************************************************
* SET WORKING DIRECTORY

cd "folder with do-files"

********************************************************************************
* SET PATHS

* version
global version vPUB

global w5_data "data folder"
global w5_log "log folder"
global w5_figures "figure folder"
global w5_tables "table folder"


********************************************************************************
* REGRESSION SELECTION

* obtain results for all observations jointly
local select_nogroups 1

* obtain results by groups separately
local select_liquidgroups 1
local select_nie 1

local select_agegroups 1
local select_wealthgroups 1
local select_incomegroups 1

* direct-indirect regressions
local select_di 1



********************************************************************************
* REGRESSION OPTIONS

*** dependent variables

* variable selection
local dependent_var_list cons_incl_housing_a cons_excl_housing_a cons_inc_a net_inc_a net_saving_a ///
	nf_income_a earned_income_a cap_inc_a net_transfers_a transfers_a taxes_a ///
	cap_inc_gross_a cap_exp_gross_a cap_inc_interest_a cap_inc_dividends_a net_interest_inc_a ///
	uncapgains_a uncapgains_housing_a uncapgains_risky_a  ///
	wealth_a debt_a housing_wealth_a liquid_a risky_a safe_a deposits_a 		

* dependent variable for income-savings regressions (must be loaded as part of dependent_var_list)
global dependent_var_di cons_excl_housing_a
 
* highest lead for change in dependent variable in the local projections (h=0,1,...,NN)
global NN 5

* number of lags of the shock included as independent variables (0,1,...)
global sLag 3

********************************************************************************
*** other

* run on full dataset (all) or sub-sample (s = 1%, m = 5%, med = 20%, med5 = 50%)
local sample all

* for Driscoll-Kraay standard errors, maximum lag in autocorrelation structure considered (default is floor[4*(T/100)^(2/9)])
global DK_lag 2

* print regression output on screen and log file (0: no, 1: yes)
global show_output 1



********************************************************************************
* LOAD DATA

u ${w5_data}/${version}_monetary_`sample', replace
tsset lnr year


********************************************************************************
* RUN LOCAL PROJECTIONS

* on all observations
if `select_nogroups'==1 {

foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_all_rta.do 

}

}




* on liquid asset groups seperately
if `select_liquidgroups'==1 {

global group_type liquid

egen group = xtile(Bliquid_assets_a), n(10) by(year)

do ${version}_micro_groups_cons_inc_diff.do
do ${version}_micro_groups_nie.do
do ${version}_micro_groups_nie_bal.do

foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_groups_rti.do
do ${version}_micro_groups_rti_bal.do
do ${version}_micro_groups_rti_nostocks.do

}

drop group
}



* on net interest exposure groups seperately
if `select_nie'==1 {

global group_type nie
gen Bnie=Bdeposits_a - Bdebt_a
egen group = xtile(Bnie), n(10) by(year)

do ${version}_micro_groups_nie.do
do ${version}_micro_groups_nie_bal.do


foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_groups_rti.do
do ${version}_micro_groups_rti_bal.do

}

drop group
}



* on age groups seperately
if `select_agegroups'==1 {

global group_type age


* make ten groups
gen group = .
forval j = 1/9 {
qui replace group = `j ' if age_a >= 25 + (`j'-1)*5 & age_a < 25 + `j'*5
}
qui replace group = 10 if age_a >= 25+9*5

do ${version}_micro_groups_nie.do
do ${version}_micro_groups_nie_bal.do


foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_groups_rti.do
do ${version}_micro_groups_rti_bal.do
}

drop group
}


* on wealth groups seperately
if `select_wealthgroups'==1 {

global group_type wealth

* In each t, group number assigned based on wealth at end of t-1 (comand requires the 'egenmore' package)
egen group = xtile(Bwealth_a), n(10) by(year)


do ${version}_micro_groups_nie.do
do ${version}_micro_groups_nie_bal.do

foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_groups_rti.do
do ${version}_micro_groups_rti_bal.do

}

drop group
}



* on income groups seperately
if `select_incomegroups'==1 {

global group_type income

* In each t, group number assigned based on wealth at end of t-1 (comand requires the 'egenmore' package)
egen group = xtile(net_inc_a), n(10) by(year)

do ${version}_micro_groups_nie.do
do ${version}_micro_groups_nie_bal.do


foreach xx of local dependent_var_list {
global dependent_var "`xx'"

do ${version}_micro_groups_rti.do
do ${version}_micro_groups_rti_bal.do

}

drop group
}



********************************************************************************
* DIRECT-INDIRECT REGRESSIONS
********************************************************************************

if `select_di'==1 {
do ${version}_micro_direct_indirect.do
}

