/*
This file estimates local projection on the whole sample. 
RTA means relative to average (of dependent variable). 
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_all_rta_${dependent_var}.log, replace


********************************************************************************
* MAKE VARIABLES


bys year: egen ${dependent_var}_avg = mean(${dependent_var})

* generate average
tsset lnr year

forval j = 0/$NN  {
	qui gen ${dependent_var}_d`j' = ((f`j'.$dependent_var  - l1.$dependent_var )/abs(l1.${dependent_var}_avg)) *100
	}

* generate control vars
g control_1 = ((l1.$dependent_var - l2.$dependent_var )/abs(l2.${dependent_var}_avg)) *100
g control_2 = ((l2.$dependent_var - l3.$dependent_var )/abs(l3.${dependent_var}_avg)) *100

		
********************************************************************************
* LOCAL PROJECTIONS

* make matrices ready
matrix res = J($NN+1,1,0)
matrix seRes = J($NN+1,1,0)
matrix NObs = J($NN+1,1,0)

forval j=0/$NN {
	
	
	eststo: qui xtscc ${dependent_var}_d`j' shock* control_*, fe lag($DK_lag)
	
	*store results
	local jnum = `j'+1
	matrix beta = e(b)
	matrix res[`jnum',1] = beta[1,1]
	mat VV = e(V)
	matrix seRes[`jnum',1] = sqrt(VV[1,1])
	matrix NObs[`jnum',1] = e(N)
	
}
	
* show estimates
if $show_output==1 {
	esttab, se compress replace
}

eststo clear

* delete variables
drop ${dependent_var}_d* control_* *_avg


********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_all_rta_${dependent_var}.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)
	

********************************************************************************
* CLOSE

log close
