/*
This file estimates local projection in the whole sample. 
RTI means relative to income. 
BAL means balanced sample. 
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_all_rti_bal_${dependent_var}.log, replace


********************************************************************************
* MAKE VARIABLES

forval j = 0/$NN  {
		qui gen ${dependent_var}_d`j' = ( f`j'.$dependent_var - l1.$dependent_var )/abs(l1.net_inc_a) *100
	}

	
g control_1 = ((l1.$dependent_var - l2.$dependent_var )/abs(l2.net_inc_a)) *100
g control_2 = ((l2.$dependent_var - l3.$dependent_var )/abs(l3.net_inc_a)) *100	
gen balance = ${dependent_var}_d0 != . & ${dependent_var}_d1 != . & ${dependent_var}_d2 != . & ${dependent_var}_d3 != . & ${dependent_var}_d4 != . & ${dependent_var}_d5 != .



		
********************************************************************************
* LOCAL PROJECTIONS

* make matrices ready
matrix res = J($NN+1,1,0)
matrix seRes = J($NN+1,1,0)
matrix NObs = J($NN+1,1,0)

forval j=0/$NN {
	
	eststo: qui xtscc ${dependent_var}_d`j' shock* control_* $demogr_controls if balance == 1, fe lag($DK_lag)
	
	*store results
	local jnum = `j'+1
	matrix beta = e(b)
	matrix res[`jnum',1] = beta[1,1]
	mat VV = e(V)
	matrix seRes[`jnum',1] = sqrt(VV[1,1])
	matrix NObs[`jnum',1] = e(N)
	
}
	
* show estimates
if $show_output==1 {
	esttab, se compress replace
}
eststo clear

* delete log-differences
drop ${dependent_var}_d* control_* balance

********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_all_rti_bal_${dependent_var}.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)
	

********************************************************************************
* CLOSE

log close
