/*
This file estimates local projection on the whole sample for the setup where we
control for income movements. 
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_direct_indirect.log, replace


********************************************************************************
* SELECT LOTTERY WINNERS

* drop multiple lottery winners
bys lnr: egen sumLott = sum(lottery_a != 0)
keep if sumLott <= 1
drop sumLott

* drop very large prizes
gen tag = lottery_a > 50000
bys lnr: egen sumTag = sum(tag)
drop if sumTag != 0
drop tag sumTag


********************************************************************************
* MAKE VARIABLES

bys year: egen ${dependent_var_di}_avg = mean(${dependent_var_di})
tsset lnr year

* nonfinancial income should be disposable income excluding net capital income in this exercise
replace nf_income_a = nf_income_a - taxes_a

* log differences of dependent variable for h=0,1,...,NN
foreach var of varlist cons_excl_housing_a net_inc_a nf_income_a earned_income_a transfers_a taxes_a cap_inc_a cap_inc_gross_a cap_exp_gross_a cap_inc_dividends_a cap_inc_interest_a uncapgains_a uncapgains_stocks_a uncapgains_housing_a uncapgains_mfund_a {
	forval j = 0/$NN  {
		qui gen `var'_d`j' = ((f`j'.`var'- l1.`var')/ l1.${dependent_var_di}_avg ) *100
	}
}

forval j = 0/$NN  {
	qui gen lottery_a_d`j' = (f`j'.lottery_a/ l1.${dependent_var_di}_avg ) *100
	qui replace lottery_a_d`j' = 0  if lottery_a_d`j' == .
}

g control_1 = ((l1.$dependent_var_di - l2.$dependent_var_di )/abs(l2.${dependent_var_di}_avg)) *100
g control_2 = ((l2.$dependent_var_di - l3.$dependent_var_di )/abs(l3.${dependent_var_di}_avg)) *100

gen balance = ${dependent_var_di}_d0 != . & ${dependent_var_di}_d1 != . & ${dependent_var_di}_d2 != . & ${dependent_var_di}_d3 != . & ${dependent_var_di}_d4 != . & ${dependent_var_di}_d5 != .
keep if balance == 1
	

********************************************************************************
* 1: PLAIN
********************************************************************************


matrix res = J($NN+1,1,0)
matrix seRes = J($NN+1,1,0)
matrix NObs = J($NN+1,1,0)	
eststo clear

forval j=0/$NN {

	eststo: qui xtscc ${dependent_var_di}_d`j' shock* control_* if balance == 1, fe lag($DK_lag)
	est store plain_`j'

	*store results
	local jnum = `j'+1
	matrix beta = e(b)
	matrix res[`jnum',1] = beta[1,1]
	mat VV = e(V)
	matrix seRes[`jnum',1] = sqrt(VV[1,1])
	matrix NObs[`jnum',1] = e(N)
}

* show estimates
if $show_output==1 {
esttab, se compress replace
}
eststo clear

putexcel set ${w5_tables}/${version}_micro_di_plain.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)

	
********************************************************************************
* 2: NF_INCOME CONTROLS SEPARATED
********************************************************************************
	
	
* make matrices ready
matrix res = J($NN+1,1,0)
matrix seRes = J($NN+1,1,0)
matrix NObs = J($NN+1,1,0)	
eststo clear


eststo: qui xtscc ${dependent_var_di}_d0 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[1,1] = beta[1,1]
mat VV = e(V)
matrix seRes[1,1] = sqrt(VV[1,1])
matrix NObs[1,1] = e(N)


eststo: qui xtscc ${dependent_var_di}_d1 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* earned_income_a_d1* cap_exp_gross_a_d1* cap_inc_interest_a_d1* cap_inc_dividends_a_d1* transfers_a_d1* taxes_a_d1* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[2,1] = beta[1,1]
mat VV = e(V)
matrix seRes[2,1] = sqrt(VV[1,1])
matrix NObs[2,1] = e(N)

eststo: qui xtscc ${dependent_var_di}_d2 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* earned_income_a_d1* cap_exp_gross_a_d1* cap_inc_interest_a_d1* cap_inc_dividends_a_d1* transfers_a_d1* taxes_a_d1* earned_income_a_d2* cap_exp_gross_a_d2* cap_inc_interest_a_d2* cap_inc_dividends_a_d2* transfers_a_d2* taxes_a_d2* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[3,1] = beta[1,1]
mat VV = e(V)
matrix seRes[3,1] = sqrt(VV[1,1])
matrix NObs[3,1] = e(N)


eststo: qui xtscc ${dependent_var_di}_d3 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* earned_income_a_d1* cap_exp_gross_a_d1* cap_inc_interest_a_d1* cap_inc_dividends_a_d1* transfers_a_d1* taxes_a_d1* earned_income_a_d2* cap_exp_gross_a_d2* cap_inc_interest_a_d2* cap_inc_dividends_a_d2* transfers_a_d2* taxes_a_d2* earned_income_a_d3* cap_exp_gross_a_d3* cap_inc_interest_a_d3* cap_inc_dividends_a_d3* transfers_a_d3* taxes_a_d3* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[4,1] = beta[1,1]
mat VV = e(V)
matrix seRes[4,1] = sqrt(VV[1,1])
matrix NObs[4,1] = e(N)

eststo: qui xtscc ${dependent_var_di}_d4 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* earned_income_a_d1* cap_exp_gross_a_d1* cap_inc_interest_a_d1* cap_inc_dividends_a_d1* transfers_a_d1* taxes_a_d1* earned_income_a_d2* cap_exp_gross_a_d2* cap_inc_interest_a_d2* cap_inc_dividends_a_d2* transfers_a_d2* taxes_a_d2* earned_income_a_d3* cap_exp_gross_a_d3* cap_inc_interest_a_d3* cap_inc_dividends_a_d3* transfers_a_d3* taxes_a_d3* earned_income_a_d4* cap_exp_gross_a_d4* cap_inc_interest_a_d4* cap_inc_dividends_a_d4* transfers_a_d4* taxes_a_d4* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[5,1] = beta[1,1]
mat VV = e(V)
matrix seRes[5,1] = sqrt(VV[1,1])
matrix NObs[5,1] = e(N)

eststo: qui xtscc ${dependent_var_di}_d5 shock* control_* earned_income_a_d0* cap_exp_gross_a_d0* cap_inc_interest_a_d0* cap_inc_dividends_a_d0* transfers_a_d0* taxes_a_d0* earned_income_a_d1* cap_exp_gross_a_d1* cap_inc_interest_a_d1* cap_inc_dividends_a_d1* transfers_a_d1* taxes_a_d1* earned_income_a_d2* cap_exp_gross_a_d2* cap_inc_interest_a_d2* cap_inc_dividends_a_d2* transfers_a_d2* taxes_a_d2* earned_income_a_d3* cap_exp_gross_a_d3* cap_inc_interest_a_d3* cap_inc_dividends_a_d3* transfers_a_d3* taxes_a_d3* earned_income_a_d4* cap_exp_gross_a_d4* cap_inc_interest_a_d4* cap_inc_dividends_a_d4* transfers_a_d4* taxes_a_d4* earned_income_a_d5* cap_exp_gross_a_d5* cap_inc_interest_a_d5* cap_inc_dividends_a_d5* transfers_a_d5* taxes_a_d5* if balance == 1, fe lag($DK_lag)

*store results
matrix beta = e(b)
matrix res[6,1] = beta[1,1]
mat VV = e(V)
matrix seRes[6,1] = sqrt(VV[1,1])
matrix NObs[6,1] = e(N)
	
	
* show estimates
if $show_output==1 {
esttab, se compress replace
}
eststo clear

putexcel set ${w5_tables}/${version}_micro_di_nocy_sep.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)	
	
	
	
********************************************************************************
* 3: LOTTERY IV
********************************************************************************	


* make matrices ready
matrix res = J($NN+1,1,0)
matrix seRes = J($NN+1,1,0)
matrix NObs = J($NN+1,1,0)	
eststo clear

* 0
eststo: qui xtivreg2 ${dependent_var_di}_d0 shock_l0 (nf_income_a_d0 =lottery_a_d0) shock_l1 shock_l2 shock_l3 control_* if balance == 1, fe first dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[1,1] = beta[1,2]
mat VV = e(V)
matrix seRes[1,1] = sqrt(VV[2,2])
matrix NObs[1,1] = e(N)


* 1
eststo: qui xtivreg2 ${dependent_var_di}_d1 shock_l0 (nf_income_a_d0 nf_income_a_d1 = lottery_a_d0 lottery_a_d1) shock_l1 shock_l2 shock_l3 control_*  if balance == 1, fe first dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[2,1] = beta[1,3]
mat VV = e(V)
matrix seRes[2,1] = sqrt(VV[3,3])
matrix NObs[2,1] = e(N)


* 2
eststo: qui xtivreg2 ${dependent_var_di}_d2 shock_l0 (nf_income_a_d0 nf_income_a_d1 nf_income_a_d2 =lottery_a_d0 lottery_a_d1 lottery_a_d2) shock_l1 shock_l2 shock_l3 control_* if balance == 1, fe first dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[3,1] = beta[1,4]
mat VV = e(V)
matrix seRes[3,1] = sqrt(VV[4,4])
matrix NObs[3,1] = e(N)


* 3
eststo: qui xtivreg2 ${dependent_var_di}_d3 shock_l0 (nf_income_a_d0 nf_income_a_d1 nf_income_a_d2 nf_income_a_d3 = lottery_a_d0 lottery_a_d1 lottery_a_d2 lottery_a_d3) shock_l1 shock_l2 shock_l3 control_* if balance == 1, fe first dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[4,1] = beta[1,5]
mat VV = e(V)
matrix seRes[4,1] = sqrt(VV[5,5])
matrix NObs[4,1] = e(N)


* 4
eststo: qui xtivreg2 ${dependent_var_di}_d4 shock_l0 (nf_income_a_d0 nf_income_a_d1 nf_income_a_d2 nf_income_a_d3 nf_income_a_d4 = lottery_a_d0 lottery_a_d1 lottery_a_d2 lottery_a_d3 lottery_a_d4) shock_l1 shock_l2 shock_l3 control_* if balance == 1, fe first dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[5,1] = beta[1,6]
mat VV = e(V)
matrix seRes[5,1] = sqrt(VV[6,6])
matrix NObs[5,1] = e(N)


* 5
eststo: qui xtivreg2 ${dependent_var_di}_d5 shock_l0 (nf_income_a_d0 nf_income_a_d1 nf_income_a_d2 nf_income_a_d3 nf_income_a_d4 nf_income_a_d5 = lottery_a_d0 lottery_a_d1 lottery_a_d2 lottery_a_d3 lottery_a_d4 lottery_a_d5) shock_l1 shock_l2 shock_l3 control_* if balance == 1, fe dkraay($DK_lag)

mat fstat = e(first)
estadd scalar fs = fstat[4,1]

matrix beta = e(b)
matrix res[6,1] = beta[1,7]
mat VV = e(V)
matrix seRes[6,1] = sqrt(VV[7,7])
matrix NObs[6,1] = e(N)
	

* show estimates
if $show_output==1 {
esttab, keep(shock_l0* nf_income_a*) se compress stats(N fs) replace

}
eststo clear

putexcel set ${w5_tables}/${version}_micro_di_lottery.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)


********************************************************************************
* CLEAN UP VARIABLES

drop control_*
drop balance
drop *d0 *d1 *d2 *d3 *d4 *d5
drop group
drop ${dependent_var_di}_avg

********************************************************************************
* CLOSE

log close
