/*
This file estimates local projection by groups. 
CONS_INC means consumption/income ratio.
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_${group_type}groups_cons_inc_diff.log, replace


********************************************************************************
* MAKE VARIABLES

tsset lnr year

forval j = 0/$NN  {
	qui gen ${dependent_var}_d`j' = (f`j'.cons_excl_housing_a/f`j'.net_inc_a - l1.cons_excl_housing_a/l1.net_inc_a) *100
	}

* generate control vars
g control_1 = (l1.cons_excl_housing_a/l1.net_inc_a - l2.cons_excl_housing_a/l2.net_inc_a ) *100
g control_2 = (l2.cons_excl_housing_a/l2.net_inc_a - l3.cons_excl_housing_a/l3.net_inc_a) *100	

	
********************************************************************************
* LOCAL PROJECTIONS

* calculate number of groups used
qui su group, meanonly 
local group_nb = r(max)		
		
* make matrices ready
matrix res = J(($NN+1)*`group_nb',1,0)
matrix seRes = J(($NN+1)*`group_nb',1,0)
matrix NObs = J(($NN+1)*`group_nb',1,0)		
				
forval kk=1/`group_nb' {
	preserve
	keep if group == `kk'
	
	forval j=0/$NN {

		* run regressions
		eststo: qui xtscc ${dependent_var}_d`j' shock* control_* $demogr_controls if group == `kk', fe lag($DK_lag)
		
		*store results
		local jnum = `j'+1
		matrix beta = e(b)
		matrix res[(`kk'-1)*($NN+1)+`jnum',1] = beta[1,1]
		mat VV = e(V)
		matrix seRes[(`kk'-1)*($NN+1)+`jnum',1] = sqrt(VV[1,1])
		matrix NObs[(`kk'-1)*($NN+1)+`jnum',1] = e(N)
	}
	
	* show estimates
	if $show_output==1 {
		esttab, se compress replace
	}
	
	eststo clear
	restore
}

* delete variables
drop ${dependent_var}_d* control_*
	
********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_${group_type}groups_cons_inc_diff_`group_nb'.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)


********************************************************************************
* CLOSE

log close
