/*
This file produces mean, median, p10, and p90 of net interest rate exposure by 
group where group is chosen in the vPUB_main.do file. 
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_${group_type}groups_nie.log, replace


********************************************************************************
* CONSTRUCT ESTIMATION SAMPLE

tsset lnr year

* generate variables to make sure we use the same as in the estimation
g control_0 = ((cons_excl_housing_a - l1.cons_excl_housing_a )/abs(l1.net_inc_a)) *100
g control_1 = ((l1.cons_excl_housing_a - l2.cons_excl_housing_a )/abs(l2.net_inc_a)) *100
g control_2 = ((l2.cons_excl_housing_a - l3.cons_excl_housing_a )/abs(l3.net_inc_a)) *100


cap drop SELECT
gen SELECT = control_0 != . & control_1 != . & control_2 != . & shock_l0 != . & shock_l1 != . & shock_l2 != . & shock_l3 != . 

********************************************************************************
* CREATE NET INTEREST RATE EXPOSURE VARIABLE AND SUMMARY STATS

cap drop Bnie
qui gen Bnie=Bdeposits_a - Bdebt_a

* calculate number of groups used
qui su group, meanonly 
local group_nb = r(max)		
		
* make matrices ready
matrix res = J(`group_nb',4,0)
			
forval kk=1/`group_nb' {
qui su Bnie if group == `kk' & SELECT == 1, det
matrix res[`kk',1] = r(mean)
matrix res[`kk',2] = r(p10)
matrix res[`kk',3] = r(p50)
matrix res[`kk',4] = r(p90)
}

* delete variables
drop control_* Bnie SELECT
	
********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_${group_type}groups_nie.xlsx, replace
putexcel A1 = matrix(res)


********************************************************************************
* CLOSE

log close
