/*
This file produces mean, median, p10, and p90 of net interest rate exposure by 
group where group is chosen in the vPUB_main.do file. The results are for the 
balanced sample.
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_${group_type}groups_nie_bal.log, replace


********************************************************************************
* CONSTRUCT ESTIMATION SAMPLE

tsset lnr year

forval j = 0/$NN  {
	qui gen cons_excl_housing_a_d`j' = ((f`j'.cons_excl_housing_a  - l1.cons_excl_housing_a)/abs(l1.net_inc_a)) *100
	}

g control_1 = ((l1.cons_excl_housing_a - l2.cons_excl_housing_a )/abs(l2.net_inc_a)) *100
g control_2 = ((l2.cons_excl_housing_a - l3.cons_excl_housing_a )/abs(l3.net_inc_a)) *100

cap drop SELECT
gen SELECT = cons_excl_housing_a_d0 != . & control_1 != . & control_2 != . & shock_l0 != . & shock_l1 != . & shock_l2 != . & shock_l3 != . 

gen balance = cons_excl_housing_a_d0 != . & cons_excl_housing_a_d1 != . & cons_excl_housing_a_d2 != . & cons_excl_housing_a_d3 != . & cons_excl_housing_a_d4 != . & cons_excl_housing_a_d5 != .

********************************************************************************
* CREATE NET INTEREST RATE EXPOSURE VARIABLE AND SUMMARY STATS

cap drop Bnie
gen Bnie=Bdeposits_a - Bdebt_a

* calculate number of groups used
qui su group, meanonly 
local group_nb = r(max)		
		
* make matrices ready
matrix res = J(`group_nb',4,0)
			
forval kk=1/`group_nb' {
qui su Bnie if group == `kk' & SELECT == 1 & balance == 1, det
matrix res[`kk',1] = r(mean)
matrix res[`kk',2] = r(p10)
matrix res[`kk',3] = r(p50)
matrix res[`kk',4] = r(p90)
}


* delete log-differences
drop cons_excl_housing_a_d* control_* Bnie SELECT balance
	
********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_${group_type}groups_nie_bal.xlsx, replace
putexcel A1 = matrix(res)


********************************************************************************
* CLOSE

log close
