/*
This file estimates local projection by groups. 
RTI means relative to income. 
*/

********************************************************************************
* LOG

cap log close
log using ${w5_log}/${version}_micro_${group_type}groups_rti_${dependent_var}.log, replace


********************************************************************************
* MAKE VARIABLES

* generate average
tsset lnr year

forval j = 0/$NN  {
	qui gen ${dependent_var}_d`j' = ((f`j'.$dependent_var  - l1.$dependent_var )/abs(l1.net_inc_a)) *100
	}


* generate control vars
g control_1 = ((l1.$dependent_var - l2.$dependent_var )/abs(l2.net_inc_a)) *100
g control_2 = ((l2.$dependent_var - l3.$dependent_var )/abs(l3.net_inc_a)) *100

		
********************************************************************************
* LOCAL PROJECTIONS

* calculate number of groups used
qui su group, meanonly 
local group_nb = r(max)		
		
* make matrices ready
matrix res = J(($NN+1)*`group_nb',1,0)
matrix seRes = J(($NN+1)*`group_nb',1,0)
matrix NObs = J(($NN+1)*`group_nb',1,0)		
				
forval kk=1/`group_nb' {
	preserve
	keep if group == `kk'

	forval j=0/$NN {

		* run regressions
		eststo: qui xtscc ${dependent_var}_d`j' shock* control_* if group == `kk', fe lag($DK_lag)
		
		*store results
		local jnum = `j'+1
		matrix beta = e(b)
		matrix res[(`kk'-1)*($NN+1)+`jnum',1] = beta[1,1]
		mat VV = e(V)
		matrix seRes[(`kk'-1)*($NN+1)+`jnum',1] = sqrt(VV[1,1])
		matrix NObs[(`kk'-1)*($NN+1)+`jnum',1] = e(N)
	}
	
	* show estimates
	if $show_output==1 {
		esttab, se compress replace
	}
	
	eststo clear
	restore
}

* delete variables
drop ${dependent_var}_d* control_*
	
********************************************************************************
* OUTPUT

putexcel set ${w5_tables}/${version}_micro_${group_type}groups_rti_${dependent_var}`group_nb'.xlsx, replace
putexcel A1 = matrix(res)
putexcel B1 = matrix(seRes)
putexcel C1 = matrix(NObs)

********************************************************************************
* CLOSE

log close
