
********************************************************************************
clear
cap log close
set more off

********************************************************************************
* general definitions of folders

global w5_data "choose data folder here"
global version vPUB


* load data
u $w5_data/households_9315_all, replace

tsset lnr year
* make consumption variables
g cons_excl_housing_a = net_inc_a - net_saving_a
g cons_incl_housing_a = net_inc_a - net_saving_a + adjFacRent*Bhousing_wealth_a

* merge in monetary policy shocks
merge m:1 year using $w5_data/mp_shocks_norway_w_lags, keep(match master) nogen


* make auxiliary variables
qui gen liquid_a = deposits + bonds + stocks_a + mfund_a
qui gen Bliquid_assets_a=Bdeposits_a+Bstocks_a+Bmfund_a+Bbonds_a
qui gen risky_a = stocks_a + mfund_a + stock_wealth_PE_a
qui gen net_transfers_a = transfers_a - taxes_a
qui gen nf_income_a = earned_income_a + transfers_a + inheritance_a + lottery_a
qui gen safe_a  = deposits_a + bonds_a
qui gen net_interest_inc_a = cap_inc_interest_a - cap_exp_gross_a
qui gen cons_inc_a = cons_excl_housing_a/net_inc_a
qui gen uncapgains_risky_a = uncapgains_a - uncapgains_housing_a

save $w5_data/${version}_monetary_all_pre_sample_selection, replace 
u $w5_data/${version}_monetary_all_pre_sample_selection, replace 

tsset lnr year
gen sampleEst = 1
replace sampleEst = 0 if wealth_a == 0 
replace sampleEst = 0 if net_inc_a <= grunnbelop
replace sampleEst = 0 if cons_excl_housing_a <= grunnbelop
gen temp = log(cons_excl_housing_a / l.cons_excl_housing_a)
replace sampleEst = 0 if abs(temp) > 0.5 & temp != .

keep if sampleEst == 1
drop if temp == .
drop sampleEst
drop temp


* trim on consumption to income ratio only
su cons_inc_a, d
replace cons_inc_a = . if cons_inc_a > r(p99)

********************************************************************************
* SAVE DATASET

save $w5_data/${version}_monetary_all, replace 

keep if noise < 0.5
save $w5_data/${version}_monetary_med5, replace 

keep if noise < 0.2
save $w5_data/${version}_monetary_med, replace 

keep if noise < 0.05
save $w5_data/${version}_monetary_m, replace 

keep if noise < 0.01
save $w5_data/${version}_monetary_s, replace 



